/** Copyright 2013-2018 the original author or authors from the JHipster project.
 *
 * This file is part of the JHipster project, see http://www.jhipster.tech/
 * for more information.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const Rule = require('./rule');
const RuleLevels = require('./rule_levels');

module.exports = {
  ENT_SHORTER_DECL: new Rule({
    name: 'ShorterEntityDeclaration',
    level: RuleLevels.WARNING,
    comment: 'When an entity does not have any field, it is possible to omit the curly braces.'
  }),
  ENT_OPTIONAL_TABLE_NAME: new Rule({
    name: 'OptionalEntityTableName',
    level: RuleLevels.WARNING,
    comment: 'Setting custom table names is possible, but not recommended.'
  }),
  FLD_OPTIONAL_COMMAS: new Rule({
    name: 'OptionalFieldCommas',
    level: RuleLevels.INFO,
    comment: 'While commas are supported, they are not mandatory if only one field is declared per line.'
  }),
  OPT_IMPROVABLE_ENTITY_LIST: new Rule({
    name: 'ImprovableOptionEntityList',
    level: RuleLevels.INFO,
    comment: 'If an option is available for every entity, it is possible to use the \'*\' syntax and/or ' +
             'the \'except\' syntax.'
  }),
  REL_INDIVIDUAL_DECL: new Rule({
    name: 'IndividualRelationshipDeclaration',
    level: RuleLevels.WARNING,
    comment: 'It is preferable to group relationships by type instead of declaring them one by one.'
  }),
  REL_MISSING_INJECTED_FIELD: new Rule({
    name: 'MissingRelationshipInjectedField',
    level: RuleLevels.WARNING,
    comment: 'Even if at least one injected field is set if none are declared, it\'s better to specify one.'
  })
};
